==> jaguar_jwt-0.1.1.tar.gz: test/decoding/validation.dart <==
library test.validation;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';
import 'package:dart_jwt/dart_jwt.dart';

main() {
  group('Validation', () {
    test('issuer.mismatch', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new JwtAuthorizationContext(
          new JwaSymmetricKeySignatureContext('secret'), 'kleak');

      ConstraintViolations violations;
      try {
        decoder.decodeToken(encoded);
      } on ConstraintViolations catch (e) {
        violations = e;
      }

      expect(violations, isNotNull);
      expect(violations.violations, hasLength(1));
      expect(violations.violations.first.message, 'Invalid issuer: "teja"');
    });

    test('audience.mismatch', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new JwtAuthorizationContext(
          new JwaSymmetricKeySignatureContext('secret'), 'teja',
          audience: ["teachers"]);

      ConstraintViolations violations;
      try {
        decoder.decodeToken(encoded);
      } on ConstraintViolations catch (e) {
        violations = e;
      }

      expect(violations, isNotNull);
      expect(violations.violations, hasLength(1));
      expect(violations.violations.first.message, 'Invalid audience!');
    });
  });
}

==> jaguar_jwt-0.2.0.tar.gz: test/decoding/validation.dart <==
library test.validation;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';
import 'package:dart_jwt/dart_jwt.dart';

main() {
  group('Validation', () {
    test('issuer.mismatch', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new AuthorizationConf(
          new JwaSymmetricKeySignatureContext('secret'), 'kleak');

      ConstraintViolations violations;
      try {
        decoder.decodeToken(encoded);
      } on ConstraintViolations catch (e) {
        violations = e;
      }

      expect(violations, isNotNull);
      expect(violations.violations, hasLength(1));
      expect(violations.violations.first.message, 'Invalid issuer: "teja"');
    });

    test('audience.mismatch', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new AuthorizationConf(
          new JwaSymmetricKeySignatureContext('secret'), 'teja',
          audience: ["teachers"]);

      ConstraintViolations violations;
      try {
        decoder.decodeToken(encoded);
      } on ConstraintViolations catch (e) {
        violations = e;
      }

      expect(violations, isNotNull);
      expect(violations.violations, hasLength(1));
      expect(violations.violations.first.message, 'Invalid audience!');
    });
  });
}
